# copyright (C) 1997-2001 Jean-Luc Fontaine (mailto:jfontain@free.fr)
# this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu

set rcsId {$Id: minimal.tcl,v 1.6 2001/01/14 13:11:31 jfontain Exp $}

# the absolute minimal module file (see documented code in random.tcl module file or HTML documentation)

package provide minimal [lindex {$Revision: 1.6 $} 1]

namespace eval minimal {

    array set data {
        updates 0
        0,label column 0,type ascii 0,message {column title}
        pollTimes 5
        sort {0 increasing}
        helpText {This is a minimal demonstration module for moodss.}
    }

    proc update {} {
        variable data

        set data(0,0) data
        incr data(updates)
    }
}
